Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(298)

Unified Diff: net/dns/mojo_host_resolver_impl.h

Issue 2351513002: net: rename BoundNetLog to NetLogWithSource (Closed)
Patch Set: one more fix, content bound_net_log_ Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/dns/mojo_host_resolver_impl.h
diff --git a/net/dns/mojo_host_resolver_impl.h b/net/dns/mojo_host_resolver_impl.h
index b0b11abb50bafcf17ea5d4cbbff08234bc8e1426..de2e354f4c5e7a95d51f1e0ef3f83b8c1a17c961 100644
--- a/net/dns/mojo_host_resolver_impl.h
+++ b/net/dns/mojo_host_resolver_impl.h
@@ -24,7 +24,8 @@ class HostResolver;
class MojoHostResolverImpl {
public:
// |resolver| is expected to outlive |this|.
- MojoHostResolverImpl(net::HostResolver* resolver, const BoundNetLog& net_log);
+ MojoHostResolverImpl(net::HostResolver* resolver,
+ const NetLogWithSource& net_log);
~MojoHostResolverImpl();
void Resolve(interfaces::HostResolverRequestInfoPtr request_info,
@@ -41,8 +42,8 @@ class MojoHostResolverImpl {
// Resolver for resolving incoming requests. Not owned.
net::HostResolver* resolver_;
- // The BoundNetLog to be passed to |resolver_| for all requests.
- const BoundNetLog net_log_;
+ // The NetLogWithSource to be passed to |resolver_| for all requests.
+ const NetLogWithSource net_log_;
// All pending jobs, so they can be cancelled when this service is destroyed.
// Owns all jobs.

Powered by Google App Engine
This is Rietveld 408576698